@@ -4,6 +4,17 @@ import os
 import sys
 from getkey import getkey
 
+def flatten(lst: list) -> list:
+    r"""
+    flattens a list of lists or tuples. 
+    """
+    ret = []
+    for item in lst:
+        if isinstance(item, (list, tuple)):
+            ret += flatten(item)
+        else:
+            ret.append(item)
+    return ret
 
 def get_user_choice(prompt: str = 'please confirm', choices: list = ['y', 'n']):
     while(True):
@@ -21,8 +32,8 @@ def get_user_choice(prompt: str = 'please confirm', choices: list = ['y', 'n']):
     return key
 
 
-def print_with_time(string):
-    print('[{}] '.format(str(datetime.datetime.now())) + string)
+def print_with_time(string, **kwargs):
+    print('[{}] '.format(str(datetime.datetime.now())) + string, **kwargs)
     sys.stdout.flush()
 
 
